# yaqd-ekspla

[![PyPI](https://img.shields.io/pypi/v/yaqd-ekspla)](https://pypi.org/project/yaqd-ekspla)
[![Conda](https://img.shields.io/conda/vn/conda-forge/yaqd-ekspla)](https://anaconda.org/conda-forge/yaqd-ekspla)
[![yaq](https://img.shields.io/badge/framework-yaq-orange)](https://yaq.fyi/)
[![black](https://img.shields.io/badge/code--style-black-black)](https://black.readthedocs.io/)
[![ver](https://img.shields.io/badge/calver-YYYY.M.MICRO-blue)](https://calver.org/)
[![log](https://img.shields.io/badge/change-log-informational)](https://gitlab.com/yaq/yaqd-ekspla/-/blob/main/CHANGELOG.md)

yaq daemons for Ekspla laser systems

This package contains the following daemon(s):

- https://yaq.fyi/daemons/ekspla-nt340


# ekspla-nt340 notes
* Use a straight-through serial cable to connect the computer and OPO. 

